@@ -6,8 +6,12 @@ import typing as t
 from tmuxp.config_reader import ConfigReader
 from tmuxp.workspace.finders import find_workspace_file, get_workspace_dir
 
+from .. import exc
 from .utils import prompt_yes_no
 
+if t.TYPE_CHECKING:
+    AllowedFileTypes = t.Literal["json", "yaml"]
+
 
 def create_convert_subparser(
     parser: argparse.ArgumentParser,
@@ -35,6 +39,13 @@ def create_convert_subparser(
     return parser
 
 
+class ConvertUnknownFileType(exc.TmuxpException):
+    def __init__(self, ext: str, *args: object, **kwargs: object) -> None:
+        return super().__init__(
+            f"Unknown filetype: {ext} (valid: [.json, .yaml, .yml])"
+        )
+
+
 def command_convert(
     workspace_file: t.Union[str, pathlib.Path],
     answer_yes: bool,
@@ -50,26 +61,31 @@ def command_convert(
 
     _, ext = os.path.splitext(workspace_file)
     ext = ext.lower()
+    to_filetype: "AllowedFileTypes"
     if ext == ".json":
         to_filetype = "yaml"
     elif ext in [".yaml", ".yml"]:
         to_filetype = "json"
     else:
-        raise Exception(f"Unknown filetype: {ext} (valid: [.json, .yaml, .yml])")
+        raise ConvertUnknownFileType(ext)
 
     configparser = ConfigReader.from_file(workspace_file)
     newfile = workspace_file.parent / (str(workspace_file.stem) + f".{to_filetype}")
 
-    export_kwargs = {"default_flow_style": False} if to_filetype == "yaml" else {}
-    new_workspace = configparser.dump(format=to_filetype, indent=2, **export_kwargs)
+    new_workspace = configparser.dump(
+        format=to_filetype,
+        indent=2,
+        **{"default_flow_style": False} if to_filetype == "yaml" else {},
+    )
 
-    if not answer_yes:
-        if prompt_yes_no(f"Convert to <{workspace_file}> to {to_filetype}?"):
-            if prompt_yes_no("Save workspace to %s?" % newfile):
-                answer_yes = True
+    if (
+        not answer_yes
+        and prompt_yes_no(f"Convert to <{workspace_file}> to {to_filetype}?")
+        and prompt_yes_no("Save workspace to %s?" % newfile)
+    ):
+        answer_yes = True
 
     if answer_yes:
-        buf = open(newfile, "w")
-        buf.write(new_workspace)
-        buf.close()
+        with open(newfile, "w") as buf:
+            buf.write(new_workspace)
         print(f"New workspace file saved to <{newfile}>.")
