@@ -16,6 +16,7 @@ import typing as t
 from libtmux.common import has_gte_version
 from libtmux.server import Server
 from libtmux.session import Session
+
 from tmuxp.types import StrPath
 
 from .. import config_reader, exc, log, util
@@ -25,9 +26,9 @@ from ..workspace.finders import find_workspace_file, get_workspace_dir
 from .utils import prompt_choices, prompt_yes_no, style, tmuxp_echo
 
 if t.TYPE_CHECKING:
-    from typing_extensions import Literal, NotRequired, TypeAlias, TypedDict
+    from typing_extensions import NotRequired, TypeAlias, TypedDict
 
-    CLIColorsLiteral: TypeAlias = Literal[56, 88]
+    CLIColorsLiteral: TypeAlias = t.Literal[56, 88]
 
     class OptionOverrides(TypedDict):
         detached: NotRequired[bool]
@@ -90,11 +91,7 @@ def set_layout_hook(session: Session, hook_name: str) -> None:
         hook_cmd.append("selectw -p")
 
     # unset the hook immediately after executing
-    hook_cmd.append(
-        "set-hook -u -t {target_session} {hook_name}".format(
-            target_session=session.id, hook_name=hook_name
-        )
-    )
+    hook_cmd.append(f"set-hook -u -t {session.id} {hook_name}")
     hook_cmd.append(f"selectw -t {attached_window.id}")
 
     # join the hook's commands with semicolons
@@ -107,23 +104,37 @@ def set_layout_hook(session: Session, hook_name: str) -> None:
     session.cmd(*cmd)
 
 
-def load_plugins(sconf: t.Any) -> t.List[t.Any]:
+def load_plugins(session_config: t.Dict[str, t.Any]) -> t.List[t.Any]:
     """
     Load and return plugins in workspace
     """
     plugins = []
-    if "plugins" in sconf:
-        for plugin in sconf["plugins"]:
+    if "plugins" in session_config:
+        for plugin in session_config["plugins"]:
             try:
                 module_name = plugin.split(".")
                 module_name = ".".join(module_name[:-1])
                 plugin_name = plugin.split(".")[-1]
+            except Exception as error:
+                tmuxp_echo(
+                    style("[Plugin Error] ", fg="red")
+                    + f"Couldn't load {plugin}\n"
+                    + style(f"{error}", fg="yellow")
+                )
+                sys.exit(1)
+
+            try:
                 plugin = getattr(importlib.import_module(module_name), plugin_name)
                 plugins.append(plugin())
             except exc.TmuxpPluginException as error:
                 if not prompt_yes_no(
-                    "%sSkip loading %s?"
-                    % (style(str(error), fg="yellow"), plugin_name),
+                    "{}Skip loading {}?".format(
+                        style(
+                            str(error),
+                            fg="yellow",
+                        ),
+                        plugin_name,
+                    ),
                     default=True,
                 ):
                     tmuxp_echo(
@@ -142,7 +153,7 @@ def load_plugins(sconf: t.Any) -> t.List[t.Any]:
     return plugins
 
 
-def _reattach(builder: WorkspaceBuilder):
+def _reattach(builder: WorkspaceBuilder) -> None:
     """
     Reattach session (depending on env being inside tmux already or not)
 
@@ -158,6 +169,7 @@ def _reattach(builder: WorkspaceBuilder):
 
     If not, ``tmux attach-session`` loads the client to the target session.
     """
+    assert builder.session is not None
     for plugin in builder.plugins:
         plugin.reattach(builder.session)
         proc = builder.session.cmd("display-message", "-p", "'#S'")
@@ -181,6 +193,7 @@ def _load_attached(builder: WorkspaceBuilder, detached: bool) -> None:
     detached : bool
     """
     builder.build()
+    assert builder.session is not None
 
     if "TMUX" in os.environ:  # tmuxp ran from inside tmux
         # unset TMUX, save it, e.g. '/tmp/tmux-1000/default,30668,0'
@@ -214,6 +227,8 @@ def _load_detached(builder: WorkspaceBuilder) -> None:
     """
     builder.build()
 
+    assert builder.session is not None
+
     if has_gte_version("2.6"):  # prepare for both cases
         set_layout_hook(builder.session, "client-attached")
         set_layout_hook(builder.session, "client-session-changed")
@@ -231,6 +246,7 @@ def _load_append_windows_to_current_session(builder: WorkspaceBuilder) -> None:
     """
     current_attached_session = builder.find_current_attached_session()
     builder.build(current_attached_session, append=True)
+    assert builder.session is not None
     if has_gte_version("2.6"):  # prepare for both cases
         set_layout_hook(builder.session, "client-attached")
         set_layout_hook(builder.session, "client-session-changed")
@@ -244,6 +260,7 @@ def _setup_plugins(builder: WorkspaceBuilder) -> Session:
     ----------
     builder: :class:`workspace.builder.WorkspaceBuilder`
     """
+    assert builder.session is not None
     for plugin in builder.plugins:
         plugin.before_script(builder.session)
 
@@ -390,7 +407,9 @@ def load_workspace(
 
     try:  # load WorkspaceBuilder object for tmuxp workspace / tmux server
         builder = WorkspaceBuilder(
-            sconf=expanded_workspace, plugins=load_plugins(expanded_workspace), server=t
+            session_config=expanded_workspace,
+            plugins=load_plugins(expanded_workspace),
+            server=t,
         )
     except exc.EmptyWorkspaceException:
         tmuxp_echo("%s is empty or parsed no workspace data" % workspace_file)
@@ -458,8 +477,9 @@ def load_workspace(
         )
 
         if choice == "k":
-            builder.session.kill_session()
-            tmuxp_echo("Session killed.")
+            if builder.session is not None:
+                builder.session.kill_session()
+                tmuxp_echo("Session killed.")
         elif choice == "a":
             _reattach(builder)
         else:
