@@ -7,6 +7,7 @@ tmuxp.log
 """
 import logging
 import time
+import typing as t
 
 from colorama import Fore, Style
 
@@ -28,7 +29,9 @@ LOG_LEVELS = {
 }
 
 
-def setup_logger(logger=None, level="INFO"):
+def setup_logger(
+    logger: t.Optional[logging.Logger] = None, level: str = "INFO"
+) -> None:
     """
     Setup logging for CLI use.
 
@@ -48,75 +51,82 @@ def setup_logger(logger=None, level="INFO"):
 
 
 def set_style(
-    message, stylized, style_before=None, style_after=None, prefix="", suffix=""
-):
+    message: str,
+    stylized: bool,
+    style_before: str = "",
+    style_after: str = "",
+    prefix: str = "",
+    suffix: str = "",
+) -> str:
     if stylized:
         return prefix + style_before + message + style_after + suffix
 
     return prefix + message + suffix
 
 
-def default_log_template(self, record, stylized=False):
-    """
-    Return the prefix for the log message. Template for Formatter.
-
-    Parameters
-    ----------
-    :py:class:`logging.LogRecord` :
-        object. this is passed in from inside the
-        :py:meth:`logging.Formatter.format` record.
-
-    Returns
-    -------
-    str
-        template for logger message
-    """
-
-    reset = Style.RESET_ALL
-    levelname = set_style(
-        "(%(levelname)s)",
-        stylized,
-        style_before=(LEVEL_COLORS.get(record.levelname) + Style.BRIGHT),
-        style_after=Style.RESET_ALL,
-        suffix=" ",
-    )
-    asctime = set_style(
-        "%(asctime)s",
-        stylized,
-        style_before=(Fore.BLACK + Style.DIM + Style.BRIGHT),
-        style_after=(Fore.RESET + Style.RESET_ALL),
-        prefix="[",
-        suffix="]",
-    )
-    name = set_style(
-        "%(name)s",
-        stylized,
-        style_before=(Fore.WHITE + Style.DIM + Style.BRIGHT),
-        style_after=(Fore.RESET + Style.RESET_ALL),
-        prefix=" ",
-        suffix=" ",
-    )
-
-    if stylized:
-        return reset + levelname + asctime + name + reset
-
-    return levelname + asctime + name
-
-
 class LogFormatter(logging.Formatter):
-    template = default_log_template
+    def template(
+        self: logging.Formatter,
+        record: logging.LogRecord,
+        stylized: bool = False,
+        **kwargs: t.Any,
+    ) -> str:
+        """
+        Return the prefix for the log message. Template for Formatter.
 
-    def __init__(self, color=True, *args, **kwargs):
-        logging.Formatter.__init__(self, *args, **kwargs)
+        Parameters
+        ----------
+        :py:class:`logging.LogRecord` :
+            object. this is passed in from inside the
+            :py:meth:`logging.Formatter.format` record.
 
-    def format(self, record):
+        Returns
+        -------
+        str
+            template for logger message
+        """
+        reset = Style.RESET_ALL
+        levelname = set_style(
+            "(%(levelname)s)",
+            stylized,
+            style_before=(LEVEL_COLORS.get(record.levelname, "") + Style.BRIGHT),
+            style_after=Style.RESET_ALL,
+            suffix=" ",
+        )
+        asctime = set_style(
+            "%(asctime)s",
+            stylized,
+            style_before=(Fore.BLACK + Style.DIM + Style.BRIGHT),
+            style_after=(Fore.RESET + Style.RESET_ALL),
+            prefix="[",
+            suffix="]",
+        )
+        name = set_style(
+            "%(name)s",
+            stylized,
+            style_before=(Fore.WHITE + Style.DIM + Style.BRIGHT),
+            style_after=(Fore.RESET + Style.RESET_ALL),
+            prefix=" ",
+            suffix=" ",
+        )
+
+        if stylized:
+            return reset + levelname + asctime + name + reset
+
+        return levelname + asctime + name
+
+    def __init__(self, color: bool = True, **kwargs: t.Any) -> None:
+        logging.Formatter.__init__(self, **kwargs)
+
+    def format(self, record: logging.LogRecord) -> str:
         try:
             record.message = record.getMessage()
         except Exception as e:
             record.message = f"Bad message ({e!r}): {record.__dict__!r}"
 
         date_format = "%H:%m:%S"
-        record.asctime = time.strftime(date_format, self.converter(record.created))
+        formatting = self.converter(record.created)
+        record.asctime = time.strftime(date_format, formatting)
 
         prefix = self.template(record) % record.__dict__
 
@@ -125,7 +135,12 @@ class LogFormatter(logging.Formatter):
         return formatted.replace("\n", "\n" + parts[0] + " ")
 
 
-def debug_log_template(self, record):
+def debug_log_template(
+    self: t.Type[logging.Formatter],
+    record: logging.LogRecord,
+    stylized: t.Optional[bool] = False,
+    **kwargs: t.Any,
+) -> str:
     """
     Return the prefix for the log message. Template for Formatter.
 
@@ -143,7 +158,7 @@ def debug_log_template(self, record):
 
     reset = Style.RESET_ALL
     levelname = (
-        LEVEL_COLORS.get(record.levelname)
+        LEVEL_COLORS.get(record.levelname, "")
         + Style.BRIGHT
         + "(%(levelname)1.1s)"
         + Style.RESET_ALL
